@@ -1,4 +1,6 @@
-package a_to_z;
+package # Hid this example package from PAUSE
+  a_to_z;
+
 use strict;
 use warnings;
 use vars qw(@ISA @list %ids %helper);
